@@ -40,7 +40,7 @@ use Mojo::Loader qw(load_class);
 # janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
 #
 
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 has 'pg';
 has 'migrations';
@@ -49,9 +49,11 @@ sub migrate($self) {
 
     my $length = scalar @{$self->migrations};
     for (my $i = 0; $i < $length; $i++) {
-        my $class = load_class @{$self->migrations}[$i]->{class};
+        my $class = @{$self->migrations}[$i]->{class};
+        my $cl = load_class $class;
+        $class->import();
         $self->pg->migrations->name(@{$self->migrations}[$i]->{name})->from_data(
-            @{$self->migrations}[$i]->{class}, @{$self->migrations}[$i]->{name}
+            $class, @{$self->migrations}[$i]->{name}
         )->migrate(@{$self->migrations}[$i]->{migration});
     }
 
